@@ -1,6 +1,7 @@
 from django.apps import AppConfig
 
 
-class MyAppConfig(AppConfig):
+class CsvDownloadConfig(AppConfig):
     name = "django_csv"
     verbose_name = "CSV Downloads"
+    default_auto_field = "django.db.models.AutoField"
